==> it-2.26.zip: it/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d allegati';
L10n::$locales['%d comments'] = '%d commenti';
L10n::$locales['%d trackbacks'] = '%d trackback';
L10n::$locales['%s reactions'] = '';
L10n::$locales['Access to content'] = 'Al contenuto';
L10n::$locales['Add a comment'] = 'Scrivi un commento';
L10n::$locales['Add ping'] = '';
L10n::$locales['Additionnal style directives'] = '';
L10n::$locales['All keywords'] = 'Tutte le parole chiave';
L10n::$locales['Archives'] = 'Archivi';
L10n::$locales['Attachments'] = 'Allegati';
L10n::$locales['Best of me'] = 'Articoli migliori';
L10n::$locales['Blog info'] = '';
L10n::$locales['Blog menu'] = 'Al menu';
L10n::$locales['By'] = 'Da';
L10n::$locales['By category'] = '';
L10n::$locales['By date'] = '';
L10n::$locales['By tag'] = '';
L10n::$locales['Categories'] = 'Categorie';
L10n::$locales['Comment'] = 'Commento';
L10n::$locales['Comments'] = 'Commenti';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = '';
L10n::$locales['Comments feed'] = 'Feed dei commenti';
L10n::$locales['Continue reading'] = 'Continua lettura';
L10n::$locales['Document not found'] = 'Documento non trovato';
L10n::$locales['Email address'] = 'Indirizzo email';
L10n::$locales['Email address is not valid'] = 'Indirizzo email non valido';
L10n::$locales['Entries feed'] = 'Feed degli articoli';
L10n::$locales['Explore archives'] = '';
L10n::$locales['Extra menu'] = 'Al menu';
L10n::$locales['From'] = '';
L10n::$locales['FromDay'] = '';
L10n::$locales['Go to homepage'] = '';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'Il codice HTML è mostrato come testo e gli indirizzi web sono automaticamente convertiti.';
L10n::$locales['Home'] = 'Home';
L10n::$locales['In'] = '';
L10n::$locales['Languages'] = 'Lingue';
L10n::$locales['Links'] = 'Link';
L10n::$locales['Name or nickname'] = 'Nome o nickname';
L10n::$locales['Next entry:'] = 'articoli successivi';
L10n::$locales['On'] = 'Il';
L10n::$locales['Page top'] = '';
L10n::$locales['Pagination'] = '';
L10n::$locales['Password needed'] = 'Password richiesta';
L10n::$locales['Password:'] = 'Password:';
L10n::$locales['Permalink'] = 'Permalink';
L10n::$locales['Powered by %s'] = 'Creato con %s';
L10n::$locales['Preview'] = 'anteprima';
L10n::$locales['Previous entry:'] = 'articoli precedenti';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Un feed RSS è il riassunto di un blog. Permette di leggere direttamente i contenuti (come gli articoli o i commenti) o loro riassunti, ed include inoltre un link alla relativa pagina del blog. Per mantenersi aggiornati sui nuovi articoli pubblicati, è possibile iscriversi attraverso un <a href="http://it.wikipedia.org/wiki/Aggregatore">aggregatore di feed</a>.';
L10n::$locales['Read'] = 'Leggi';
L10n::$locales['Remember me on this blog'] = 'Ricordami su questo blog';
L10n::$locales['Required field'] = '';
L10n::$locales['Search'] = 'Cerca';
L10n::$locales['Send'] = '';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'È sufficiente copiare il seguente URL all\'interno del proprio aggregatore:';
L10n::$locales['Subcategories'] = 'Sotto-categorie';
L10n::$locales['Subscribe'] = 'Sottoscrivi';
L10n::$locales['Subscribe to'] = 'Iscriviti a';
L10n::$locales['Suggestions:'] = '';
L10n::$locales['The document you are looking for does not exist.'] = 'Il documento richiesto non esiste.';
L10n::$locales['The list of recents posts is available'] = '';
L10n::$locales['They posted on the same topic'] = 'Hanno scritto sullo stesso argomento';
L10n::$locales['This blog\'s comments Atom feed'] = 'Feed Atom dei commenti di questo blog';
L10n::$locales['This category\'s comments Atom feed'] = 'Feed Atom dei commenti di questa categoria';
L10n::$locales['This category\'s entries Atom feed'] = 'Feed Atom degli articoli di questa categoria';
L10n::$locales['This post\'s comments Atom feed'] = 'Feed Atom dei commenti di questo articolo';
L10n::$locales['This post\'s comments feed'] = 'Feed dei commenti di questo articolo';
L10n::$locales['To content'] = 'Al contenuto';
L10n::$locales['To menu'] = 'Al menu';
L10n::$locales['To search'] = 'Alla ricerca';
L10n::$locales['Trackback URL'] = 'URL trackback';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = '';
L10n::$locales['Use search form'] = '';
L10n::$locales['Website'] = 'Sito web';
L10n::$locales['What is an RSS feed?'] = 'Che cos\'è un feed RSS?';
L10n::$locales['You must give a password to access this area.'] = 'Per accedere in quest\'area del sito è necessario inserire la password.';
L10n::$locales['You must provide a comment'] = 'È necessario inserire un commento';
L10n::$locales['You must provide a valid email address.'] = 'È necessario fornire un indirizzo email valido.';
L10n::$locales['You must provide an author name'] = 'È necessario inserire il nome dell\'autore';
L10n::$locales['Your comment'] = 'Il tuo commento';
L10n::$locales['Your comment has been published.'] = 'Il tuo commento è stato pubblicato.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Il tuo commento è stato inviato e sarà controllato prima di essere pubblicato.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'È stato trovato <strong>%2$s</strong> risultato per la ricerca di <em>%1$s</em>.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Sono stati trovati <strong>%2$s</strong> risultati per la ricerca di <em>%1$s</em>.';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Non è stato trovato alcun risultato per la ricerca di <em>%1$s</em>.';
L10n::$locales['by'] = 'da';
L10n::$locales['here'] = '';
L10n::$locales['in'] = '';
L10n::$locales['next entries'] = 'articoli successivi';
L10n::$locales['no attachments'] = 'nessun allegato';
L10n::$locales['no comments'] = 'nessuno commento';
L10n::$locales['no reactions'] = '';
L10n::$locales['no trackbacks'] = 'nessun trackback';
L10n::$locales['of'] = 'di';
L10n::$locales['on'] = 'il';
L10n::$locales['one attachment'] = 'un allegato';
L10n::$locales['one comment'] = 'un commento';
L10n::$locales['one reaction'] = 'Continua lettura';
L10n::$locales['one trackback'] = 'un trackback';
L10n::$locales['optional'] = 'facoltativo';
L10n::$locales['page'] = 'pagina';
L10n::$locales['preview'] = 'anteprima';
L10n::$locales['previous entries'] = 'articoli precedenti';
L10n::$locales['reactions'] = '';
L10n::$locales['send'] = 'invia';
L10n::$locales['toDay'] = '';

==> it-2.27.zip: it/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d allegati';
L10n::$locales['%d comments'] = '%d commenti';
L10n::$locales['%d trackbacks'] = '%d trackback';
L10n::$locales['%s reactions'] = '%s reazioni';
L10n::$locales['Access to content'] = 'Accesso ai contenuti';
L10n::$locales['Add a comment'] = 'Scrivi un commento';
L10n::$locales['Add ping'] = 'Aggiungi ping';
L10n::$locales['Additionnal style directives'] = 'Direttive di stile aggiuntivo';
L10n::$locales['All keywords'] = 'Tutte le parole chiave';
L10n::$locales['Archives'] = 'Archivi';
L10n::$locales['Attachments'] = 'Allegati';
L10n::$locales['Best of me'] = 'Articoli migliori';
L10n::$locales['Blog info'] = 'Informazioni sul blog';
L10n::$locales['Blog menu'] = 'Menu del blog';
L10n::$locales['By'] = 'Da';
L10n::$locales['By category'] = 'Per categoria';
L10n::$locales['By date'] = 'Per data';
L10n::$locales['By tag'] = 'Per tag';
L10n::$locales['Categories'] = 'Categorie';
L10n::$locales['Comment'] = 'Commento';
L10n::$locales['Comments'] = 'Commenti';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = 'I commenti possono essere formattati utilizzando una semplice sintassi wiki.';
L10n::$locales['Comments feed'] = 'Feed dei commenti';
L10n::$locales['Continue reading'] = 'Continua lettura';
L10n::$locales['Document not found'] = 'Documento non trovato';
L10n::$locales['Email address'] = 'Indirizzo email';
L10n::$locales['Email address is not valid'] = 'Indirizzo email non valido';
L10n::$locales['Entries feed'] = 'Feed degli articoli';
L10n::$locales['Explore archives'] = 'Esplora gli archivi';
L10n::$locales['Extra menu'] = 'Extra menu';
L10n::$locales['From'] = 'Da';
L10n::$locales['FromDay'] = 'Da:';
L10n::$locales['Go to homepage'] = 'Vai alla homepage';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'Il codice HTML è mostrato come testo e gli indirizzi web sono automaticamente convertiti.';
L10n::$locales['Home'] = 'Home';
L10n::$locales['In'] = 'In';
L10n::$locales['Languages'] = 'Lingue';
L10n::$locales['Links'] = 'Link';
L10n::$locales['Name or nickname'] = 'Nome o nickname';
L10n::$locales['Next entry:'] = 'Prossima voce:';
L10n::$locales['On'] = 'Il';
L10n::$locales['Page top'] = 'Pagina superiore';
L10n::$locales['Pagination'] = 'Paginazione';
L10n::$locales['Password needed'] = 'Password richiesta';
L10n::$locales['Password:'] = 'Password,';
L10n::$locales['Permalink'] = 'Permalink';
L10n::$locales['Powered by %s'] = 'Creato con %s';
L10n::$locales['Preview'] = 'Anteprima';
L10n::$locales['Previous entry:'] = 'Voce precedente:';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Un feed RSS è il riassunto di un blog. Permette di leggere direttamente i contenuti (come gli articoli o i commenti) o loro riassunti, ed include inoltre un link alla relativa pagina del blog. Per mantenersi aggiornati sui nuovi articoli pubblicati, è possibile iscriversi attraverso un <a href="http://it.wikipedia.org/wiki/Aggregatore">aggregatore di feed</a>.';
L10n::$locales['Read'] = 'Leggi';
L10n::$locales['Remember me on this blog'] = 'Ricordami su questo blog';
L10n::$locales['Required field'] = 'Campo obbligatorio';
L10n::$locales['Search'] = 'Cerca';
L10n::$locales['Send'] = 'Invia';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'È sufficiente copiare il seguente URL all\'interno del proprio aggregatore:';
L10n::$locales['Subcategories'] = 'Sotto-categorie';
L10n::$locales['Subscribe'] = 'Sottoscrivi';
L10n::$locales['Subscribe to'] = 'Iscriviti a';
L10n::$locales['Suggestions:'] = 'Suggerimenti:';
L10n::$locales['The document you are looking for does not exist.'] = 'Il documento richiesto non esiste.';
L10n::$locales['The list of recents posts is available'] = 'La lista dei post recenti è disponibile';
L10n::$locales['They posted on the same topic'] = 'Hanno scritto sullo stesso argomento';
L10n::$locales['This blog\'s comments Atom feed'] = 'Feed Atom dei commenti di questo blog';
L10n::$locales['This category\'s comments Atom feed'] = 'Feed Atom dei commenti di questa categoria';
L10n::$locales['This category\'s entries Atom feed'] = 'Feed Atom degli articoli di questa categoria';
L10n::$locales['This post\'s comments Atom feed'] = 'Feed Atom dei commenti di questo articolo';
L10n::$locales['This post\'s comments feed'] = 'Feed dei commenti di questo articolo';
L10n::$locales['To content'] = 'Al contenuto';
L10n::$locales['To menu'] = 'Al menu';
L10n::$locales['To search'] = 'Alla ricerca';
L10n::$locales['Trackback URL'] = 'URL trackback';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = 'URL che hai provato ha typos, o la pagina è stata cancellata o spostata.';
L10n::$locales['Use search form'] = 'Usa modulo di ricerca';
L10n::$locales['Website'] = 'Sito web';
L10n::$locales['What is an RSS feed?'] = 'Che cos\'è un feed RSS?';
L10n::$locales['You must give a password to access this area.'] = 'Per accedere in quest\'area del sito è necessario inserire la password.';
L10n::$locales['You must provide a comment'] = 'È necessario inserire un commento';
L10n::$locales['You must provide a valid email address.'] = 'È necessario fornire un indirizzo email valido.';
L10n::$locales['You must provide an author name'] = 'È necessario inserire il nome dell\'autore';
L10n::$locales['Your comment'] = 'Il tuo commento';
L10n::$locales['Your comment has been published.'] = 'Il tuo commento è stato pubblicato.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Il tuo commento è stato inviato e sarà controllato prima di essere pubblicato.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'È stato trovato <strong>%2$s</strong> risultato per la ricerca di <em>%1$s</em>.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Sono stati trovati <strong>%2$s</strong> risultati per la ricerca di <em>%1$s</em>.';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Non è stato trovato alcun risultato per la ricerca di <em>%1$s</em>.';
L10n::$locales['by'] = 'da';
L10n::$locales['here'] = 'qui';
L10n::$locales['in'] = 'in';
L10n::$locales['next entries'] = 'articoli successivi';
L10n::$locales['no attachments'] = 'nessun allegato';
L10n::$locales['no comments'] = 'nessun commento';
L10n::$locales['no reactions'] = 'nessuna reazione';
L10n::$locales['no trackbacks'] = 'nessun trackback';
L10n::$locales['of'] = 'di';
L10n::$locales['on'] = 'il';
L10n::$locales['one attachment'] = 'un allegato';
L10n::$locales['one comment'] = 'un commento';
L10n::$locales['one reaction'] = 'una reazione';
L10n::$locales['one trackback'] = 'un trackback';
L10n::$locales['optional'] = 'facoltativo';
L10n::$locales['page'] = 'pagina';
L10n::$locales['preview'] = 'anteprima';
L10n::$locales['previous entries'] = 'articoli precedenti';
L10n::$locales['reactions'] = 'reazioni';
L10n::$locales['send'] = 'invia';
L10n::$locales['toDay'] = 'aGiorno';
